@@ -30,8 +30,8 @@ QTEST_GUILESS_MAIN(KStandarddirsTest)
 #include <kconfig.h>
 #include <kglobal.h>
 #include <qtemporarydir.h>
-#include <QtCore/QDebug>
-#include <QtTest/QtTest>
+#include <QDebug>
+#include <QtTest>
 #include <kconfiggroup.h>
 #include <QFile>
 
@@ -281,6 +281,10 @@ void KStandarddirsTest::testFindDirs()
 
 void KStandarddirsTest::testFindResourceDir()
 {
+    if (!isKdeLibs4supportInstalled()) {
+        QSKIP("KDELibs4Support is not installed yet");
+    }
+
     const QString configDir = KGlobal::dirs()->findResourceDir("config", "foorc");
     QVERIFY(!configDir.isEmpty());
     QVERIFY2(configDir.endsWith(QLatin1String("/xdg/config/")), qPrintable(configDir));
@@ -325,7 +329,7 @@ void KStandarddirsTest::testFindExe()
     const QString fromKStdDirs = KStandardDirs::realFilePath(cmd);
     QCOMPARE(fromKStdDirs, cmd);
     const QString fromQFileInfo = QFileInfo(cmd).canonicalFilePath();
-    QVERIFY(fromQFileInfo.isEmpty()); // !! different result, since this doesn't exist as a file
+    QVERIFY2(fromQFileInfo.isEmpty(), qPrintable(QString("QFileInfo(\"" + cmd + "\").canonicalFilePath() returned \"" + fromQFileInfo + "\""))); // !! different result, since this doesn't exist as a file
 
 #ifdef Q_OS_UNIX
     // findExe with relative path
