@@ -26,11 +26,11 @@
 #include "kaboutdata.h"
 
 #include <QStandardPaths>
-#include <QtCore/QFile>
-#include <QtCore/QTextStream>
-#include <QtCore/QSharedData>
-#include <QtCore/QVariant>
-#include <QtCore/QList>
+#include <QFile>
+#include <QTextStream>
+#include <QSharedData>
+#include <QVariant>
+#include <QList>
 #include <QHash>
 
 // -----------------------------------------------------------------------------
@@ -52,7 +52,7 @@
 // at the point of getter calls (i.e. delayed translation).
 // -----------------------------------------------------------------------------
 
-class K4AboutPerson::Private
+class Q_DECL_HIDDEN K4AboutPerson::Private
 {
 public:
     KLocalizedString _name;
@@ -144,7 +144,7 @@ K4AboutPerson &K4AboutPerson::operator=(const K4AboutPerson &other)
     return *this;
 }
 
-class K4AboutLicense::Private : public QSharedData
+class Q_DECL_HIDDEN K4AboutLicense::Private : public QSharedData
 {
 public:
     Private(enum K4AboutData::LicenseKey licenseType, const K4AboutData *aboutData);
@@ -379,10 +379,10 @@ K4AboutLicense K4AboutLicense::byKeyword(const QString &rawKeyword)
 
     K4AboutData::LicenseKey license = ldict.value(keyword.toLatin1(),
                                       K4AboutData::License_Custom);
-    return K4AboutLicense(license, 0);
+    return K4AboutLicense(license, nullptr);
 }
 
-class K4AboutData::Private
+class Q_DECL_HIDDEN K4AboutData::Private
 {
 public:
     Private()
@@ -810,7 +810,7 @@ QString K4AboutData::organizationDomain() const
 const char *K4AboutData::internalBugAddress() const
 {
     if (d->_bugEmailAddress.isEmpty()) {
-        return 0;
+        return nullptr;
     }
     return d->_bugEmailAddress.constData();
 }
