@@ -25,8 +25,8 @@
 
 #include <stdio.h>
 
-#include <QtCore/QObject>
-#include <QtCore/QTimer>
+#include <QObject>
+#include <QTimer>
 #include <QActionEvent>
 #include <QDesktopWidget>
 #include <QPainter>
@@ -64,7 +64,7 @@
 
 static int block_resize = 0;
 
-class KMenuBar::KMenuBarPrivate
+class Q_DECL_HIDDEN KMenuBar::KMenuBarPrivate
 {
 public:
     KMenuBarPrivate()
